@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE SGenPrbA.h
@@ -24,13 +24,13 @@
 #include "smatrixd.h"
 
 
-template <class T>
+template <class ART>
 struct SymGenProblemA {
 
-  SymMatrixC<T> A;
-  SymMatrixD<T> B;
+  SymMatrixC<ART> A;
+  SymMatrixD<ART> B;
 
-  void MultOPv(T* v, T* w)
+  void MultOPv(ART* v, ART* w)
   // Matrix-vector multiplication w <- inv(B)*A*v.
   {
     A.MultMv(v, w);
