@@ -1,5 +1,5 @@
 /*
-   ARPACK++ v1.0 8/1/1997
+   ARPACK++ v1.2 2/20/2000
    c++ interface to ARPACK code.
 
    MODULE DCMatrxC.h
@@ -20,23 +20,23 @@
 
 #include "arcomp.h"
 
-template<class FLOAT, class INT>
-void CompMatrixC(INT n, arcomplex<FLOAT>* &A)
+template<class ARFLOAT, class ARINT>
+void CompMatrixC(ARINT n, arcomplex<ARFLOAT>* &A)
 {
 
-  INT              i, j;
-  arcomplex<FLOAT> diag, sub;
+  ARINT              i, j;
+  arcomplex<ARFLOAT> diag, sub;
 
   // Defining constants.
 
-  sub  = arcomplex<FLOAT>(1.0/(FLOAT)(n+1), 0.0);
-  diag = arcomplex<FLOAT>(4.0/(FLOAT)(n+1), 0.0);
+  sub  = arcomplex<ARFLOAT>(1.0/(ARFLOAT)(n+1), 0.0);
+  diag = arcomplex<ARFLOAT>(4.0/(ARFLOAT)(n+1), 0.0);
 
   // Creating output vector A.
 
-  A  = new arcomplex<FLOAT>[n*n];
+  A  = new arcomplex<ARFLOAT>[n*n];
 
-  for (i=0; i<n*n; i++) A[i] = arcomplex<FLOAT>(0.0, 0.0);
+  for (i=0; i<n*n; i++) A[i] = arcomplex<ARFLOAT>(0.0, 0.0);
 
   for (i=0, j=0; i<n; i++, j+=n+1) {
     if (i)      A[j-1]  = sub;
